@@ -151,7 +151,7 @@ REQUIREMENTS = [
 
 SETUP_WARNING = (
     "# THIS FILE IS CREATED AUTOMATICALLY AND ALL MANUAL CHANGES WILL BE OVERWRITTEN\n"
-    "# If you want to adjust settings in this file, change scripts/templates/{}\n\n"
+    "# If you want to adjust settings in this file, change scripts/_templates/{}\n\n"
 )
 
 
@@ -257,7 +257,7 @@ def write_from_template(
     print(f"Write `{path}`")
 
     # load template data
-    template_path = Path(__file__).parent / "templates" / template_name
+    template_path = Path(__file__).parent / "_templates" / template_name
     with template_path.open("r") as fp:
         template = Template(fp.read())
 
